@@ -19,7 +19,6 @@ from notice.settings import NOTICE_DATETIME_FORMAT
 
 
 class NoticeForm(forms.Form):
-
     class SendWayEnum(Enum):
         NO = 'no'
         NOW = 'now'
@@ -95,3 +94,23 @@ class ChangeTimingForm(forms.Form):
             if publish_at <= timezone_now():
                 raise ValidationError(ValidationFailedDetailEnum.OUTDATE.value)
         return publish_at
+
+
+class PrivateForm(forms.Form, SimpleArrayField):
+    """私信消息表单"""
+    receiver = SimpleArrayField(required=True, base_field=forms.CharField(required=False))
+    title = forms.CharField(required=False, max_length=64)
+    content = forms.CharField(required=False, max_length=64)
+
+
+class BacklogForm(forms.Form):
+    """待办消息表单"""
+    is_done = forms.BooleanField(required=False)
+    receiver = SimpleArrayField(required=True, base_field=forms.CharField(required=False))
+    initiator = forms.CharField(required=False, max_length=64)
+    initiator_name = forms.CharField(required=False, max_length=64)
+    obj_name = forms.CharField(required=False, max_length=64)
+    obj_key = forms.CharField(required=False, max_length=64)
+    obj_status = forms.CharField(required=False, max_length=64)
+    handler = SimpleArrayField(required=False, base_field=forms.CharField(required=False))
+    candidates = SimpleArrayField(required=False, base_field=forms.CharField(required=False))
